==> 2.4.zip: piwigo/language/fi_FI/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Pääkäyttäjän konfiguroiminen';
$lang['Basic configuration'] = 'Perusasetukset';
$lang['Can\'t connect to server'] = 'Ei pysty yhdistämään palvelimeen';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Yhteys palvelimeen onnistui, mutta yhteys tietokantaan on mahdotonta.';
$lang['Database configuration'] = 'Tietokannan konfiguroiminen';
$lang['Database name'] = 'Tietokannan nimi';
$lang['Database table prefix'] = 'Tietokannan taulun etuliite';
$lang['Default gallery language'] = 'Gallerian oletuskieli';
$lang['Host'] = 'Isäntäkone';
$lang['Installation'] = 'Asennus';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Tullaan näyttämään vierailijoille. Olennainen sivuston hallintaa ajatellen';
$lang['Password'] = 'Salasana';
$lang['Start Install'] = 'Aloita asennus';
$lang['User'] = 'Käyttäjä';
$lang['Webmaster login'] = 'Webmaster -kirjatuminen';
$lang['also given by your host provider'] = 'myöskin palveluntarjoajan määrittelemä';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'paikallinen isäntäkone';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'sähköpostin tulee olla muodossa xxx@yyy.eee (esim. jack@altern.org)';
$lang['user login given by your host provider'] = 'käyttäjänimi, jonka palveluntarjoaja on määrittänyt';
$lang['user password given by your host provider'] = 'käyttäjän salasana, jonka palveluntarjoaja on määrittänyt';
$lang['Congratulations, Piwigo installation is completed'] = 'Onnittelut, Piwigon asennus on onnistunut';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Älä epäröi ottaa yhteyttä, kysy apua foorumiltamme: %s';
$lang['It appears your webhost is currently running PHP %s.'] = 'Näyttää että palveluntarjoajasi käyttää PHP %s.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Tarvitsetko apua? Kysy asiasta <a href="%s">Piwigon keskustelupalstalla</a>';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Voit muokata asetuksia itse ja käynnistää Piwigon uudelleen tämän jälkeen.';
$lang['PHP 5 is required'] = 'PHP 5 vaaditaan';
$lang['Password ']['confirm'] = 'Salasana [hyväksy]';
$lang['Try to configure PHP 5'] = 'Yritä määrittää PHP 5';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Vierailijat voivat ottaa yhteyttä sivuston ylläpitäjään tätä sähköpostiosoitetta käyttäen';
$lang['Webmaster mail address'] = 'Ylläpitäjän sähköpostiosoite';
$lang['Webmaster password'] = 'Ylläpitäjän salasana';
$lang['Welcome to my photo gallery'] = 'Tervetuloa kuvagalleriaani';
$lang['enter a login for webmaster'] = 'Lisää käyttäjätunnus ylläpitäjälle';
$lang['please enter your password again'] = 'Salasana uudelleen';
$lang['webmaster login can\'t contain characters \' or "'] = 'Ylläpitäjän käyttäjätunnus ei voi sisältää \' tai " merkkejä';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Vaihtoehtoinen tapa on kopioida teksti ylläolevasta laatikosta ja liittää se tiedostoon "local/config/database.inc.php"(Varoitus: tiedoston database.inc.php tulee sisältää vain tekstiosuus, ei välejä eikä tyhjiä rivejä) ';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Konfigurointitiedoston local/config/database.inc.php luominen epäonnistui.';
$lang['Download the config file'] = 'Lataa konfigurointitiedosto';
$lang['Hope to see you back soon.'] = 'Toivottavasti näemme pian';
$lang['Just another Piwigo gallery'] = 'Yksi Piwigo -galleria lisää';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Pidä salassa, se mahdollistaa pääsyn pääkäyttäjän paneeliin';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo voi yrittää vaihtaa konfiguraation PHP 5 :seen luomalla tai muuttamalla .htaccess -tiedostoa.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ei pystynyt konfiguroimaan PHP5 :sta.';
$lang['Sorry!'] = 'Anteeksi!';
$lang['Welcome to your new installation of Piwigo!'] = 'Tervetuloa uuteen Piwigo -asennukseesi!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Voit ladata konfiguraatiotiedoston ja siirtää sen asennuksesi local/config -hakemistoon. ';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sinun tulee kääntyä hosting -palveluntarjoajasi puoleen ja kysyä kuinka voit vaihtaa PHP 5:seen itse.';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'se tulee tietokannan taulun nimen etuliitteeksi (mahdollistaa taulujen helpomman hallinnan)';
$lang['verification'] = 'vahvistus';
?>

==> 14.5.0.zip: piwigo/language/fi_FI/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Pääkäyttäjän konfiguroiminen';
$lang['Basic configuration'] = 'Perusasetukset';
$lang['Can\'t connect to server'] = 'Ei pysty yhdistämään palvelimeen';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Yhteys palvelimeen onnistui, mutta yhteys tietokantaan on mahdotonta.';
$lang['Database configuration'] = 'Tietokannan konfiguroiminen';
$lang['Database name'] = 'Tietokannan nimi';
$lang['Database table prefix'] = 'Tietokannan taulun etuliite';
$lang['Default gallery language'] = 'Gallerian oletuskieli';
$lang['Host'] = 'Isäntäkone';
$lang['Installation'] = 'Asennus';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Tullaan näyttämään vierailijoille. Olennainen sivuston hallintaa ajatellen';
$lang['Start Install'] = 'Aloita asennus';
$lang['User'] = 'Käyttäjä';
$lang['also given by your host provider'] = 'myöskin palveluntarjoajan määrittelemä';
$lang['localhost or other, supplied by your host provider'] = 'paikallinen isäntäkone';
$lang['user login given by your host provider'] = 'käyttäjänimi, jonka palveluntarjoaja on määrittänyt';
$lang['user password given by your host provider'] = 'käyttäjän salasana, jonka palveluntarjoaja on määrittänyt';
$lang['Congratulations, Piwigo installation is completed'] = 'Onnittelut, Piwigon asennus on onnistunut';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Älä epäröi ottaa yhteyttä, kysy apua foorumiltamme: %s';
$lang['It appears your webhost is currently running PHP %s.'] = 'Näyttää että palveluntarjoajasi käyttää PHP %s.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Tarvitsetko apua? Kysy asiasta <a href="%s">Piwigon keskustelupalstalla</a>';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Voit muokata asetuksia itse ja käynnistää Piwigon uudelleen tämän jälkeen.';
$lang['PHP 5 is required'] = 'PHP 5.2 vaaditaan';
$lang['Password ']['confirm'] = 'Salasana [hyväksy]';
$lang['Try to configure PHP 5'] = 'Yritä määrittää PHP 5.2';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Vierailijat voivat ottaa yhteyttä sivuston ylläpitäjään tätä sähköpostiosoitetta käyttäen';
$lang['Welcome to my photo gallery'] = 'Tervetuloa kuvagalleriaani';
$lang['enter a login for webmaster'] = 'Lisää käyttäjätunnus ylläpitäjälle';
$lang['please enter your password again'] = 'Salasana uudelleen';
$lang['webmaster login can\'t contain characters \' or "'] = 'Ylläpitäjän käyttäjätunnus ei voi sisältää \' tai " merkkejä';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Vaihtoehtoinen tapa on kopioida teksti ylläolevasta laatikosta ja liittää se tiedostoon "local/config/database.inc.php"(Varoitus: tiedoston database.inc.php tulee sisältää vain tekstiosuus, ei välejä eikä tyhjiä rivejä) ';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Konfigurointitiedoston local/config/database.inc.php luominen epäonnistui.';
$lang['Download the config file'] = 'Lataa konfigurointitiedosto';
$lang['Hope to see you back soon.'] = 'Toivottavasti näemme pian';
$lang['Just another Piwigo gallery'] = 'Yksi Piwigo -galleria lisää';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Pidä salassa, se mahdollistaa pääsyn pääkäyttäjän paneeliin';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo voi yrittää vaihtaa konfiguraation PHP 5.2 :seen luomalla tai muuttamalla .htaccess -tiedostoa.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ei pystynyt konfiguroimaan PHP5.2 :sta.';
$lang['Sorry!'] = 'Anteeksi!';
$lang['Welcome to your new installation of Piwigo!'] = 'Tervetuloa uuteen Piwigo -asennukseesi!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Voit ladata konfiguraatiotiedoston ja siirtää sen asennuksesi local/config -hakemistoon. ';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sinun tulee kääntyä hosting -palveluntarjoajasi puoleen ja kysyä kuinka voit vaihtaa PHP 5.2 :seen itse.';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'se tulee tietokannan taulun nimen etuliitteeksi (mahdollistaa taulujen helpomman hallinnan)';
$lang['verification'] = 'vahvistus';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP-versio %s vaaditaan. (sinulla on PHP-versio %s)';
